# This file is a part of the RPA program
# (Robust Probabilistic Averaging) 
# http://bioconductor.org/packages/release/bioc/html/RPA.html

# Copyright (C) 2008-2011 Leo Lahti <leo.lahti@iki.fi>. All rights reserved.

# This program is free software; you can redistribute it and/or modify
# it under the terms of the FreeBSD License.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

rpa.plot <- function (dat, rpa.fit.object = NULL, highlight.probes = NULL, pcol = "darkgrey", mucol = "black", ecol = "red", cex.lab = 1.5, cex.axis = 1, external.signal = NULL, main = "", plots = "all") {

  # If no model given, calculate fit a new model on the data
  if (is.null(rpa.fit.object)) { rpa.fit.object <- rpa.fit(dat) }
  # Override given data with the one in rpa.fit object
  dat <- rpa.fit.object$data
  
  # number of probes
  Np <- nrow(dat)

  mu <- rpa.fit.object$mu
  s2 <- rpa.fit.object$sigma2
  af <- rpa.fit.object$affinity
  
  # image limits
  ylims <- range(c(as.vector(dat), mu))

  if (plots == "all") {
    par(mfrow = c(3, 1))
  }
  
  # expression figure
  plot(c(1,2,3), type = 'n',
       xlim = c(1, ncol(dat)),
       ylim = ylims,
       xlab = "Samples",
       ylab = "Signal",
       cex.lab = cex.lab,
       cex.axis = cex.axis,
       main = main,
       las = 1, xaxt = 'n')
  axis(1, at = 1:ncol(dat), labels = colnames(dat))

  for (i in 1:Np) { lines(dat[i, ], col = pcol, lwd = 2) }

  if (!is.null(highlight.probes)) {
    lines(dat[highlight.probes, ], lty = 2, lwd = 2) 
  }

  # Plot the summary
  lines(mu, col = mucol, lwd = 2)

  # Plot external signal
  if (!is.null(external.signal)) {
    lines(external.signal, col = ecol, lwd = 2)
  }

  if (plots == "all") {
  
    # Plot probe variances
    barplot(s2, main = "Probe variances",
          ylab = "Variance", xlab = "Probe index",
          names.arg = 1:length(s2),
          las = 1,
          cex.lab = cex.lab,
          cex.axis = cex.axis)

    # Plot probe affinities
    barplot(af, main = "Probe affinities",
          ylab = "Affinity", xlab = "Probe index",
          names.arg = 1:length(af),
          las = 1,
          cex.lab = cex.lab,
          cex.axis = cex.axis)  

  }
  
  rpa.fit.object

}
